# intraloxsensing-python-client

A python client for interacting with IntraloxSensing.  All returns will be a 'requests' [response object](https://requests.readthedocs.io/en/latest/api/#requests.Response).

Additional endpoints will be added as functionality is required.
